/**
 * Copyright (c) 2018-present, heineiuo.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */
/// <reference types="node" />
import { Options, ReadOptions, WriteOptions, IteratorOptions } from './Options';
import { WriteBatch } from './WriteBatch';
export default class Database {
    constructor(dbpath: string, options?: Options);
    private writers;
    private tmpBatch;
    private _internalKeyComparator;
    private _backgroundCompactionScheduled;
    private _dbpath;
    private _sn;
    private _ok;
    private _status;
    private _log;
    private _logFileNumber;
    private _memtable;
    private _immtable;
    private _versionSet;
    private _manualCompaction;
    private _bgError;
    private pendingOutputs;
    private snapshots;
    private _stats;
    private _options;
    private _tableCache;
    private lockfile;
    private readonly userComparator;
    private shouldInit;
    private initVersionEdit;
    private recoverWrapper;
    private recover;
    private recoverLogFile;
    ok(): Promise<boolean>;
    destroy(): Promise<void>;
    iterator(options?: IteratorOptions): AsyncIterableIterator<{
        key: Buffer;
        value: Buffer;
    }>;
    /**
     * db.get -> memtable.get -> imm.get -> versionCurrent.get ->
     * versionCurrent.forEachOverlapping -> tableCache.get -> tableCache.findTable ->
     * table.get
     */
    get(userKey: string | Buffer, options?: ReadOptions): Promise<Buffer | void>;
    /**
     * TODO Trigger minor compaction's condition
     * 1. check if memtable bigger then 4mb
     * 2. check if this._immtable is not null（transfer memtable to sstable）
     */
    put(key: string | Buffer, value: string | Buffer, options?: WriteOptions): Promise<void>;
    del(key: string | Buffer, options?: WriteOptions): Promise<void>;
    batch(batch: WriteBatch, options?: WriteOptions): Promise<void>;
    private write;
    private buildBatchGroup;
    /**
     * if force is true, force compact
     */
    private makeRoomForWrite;
    private maybeScheduleCompaction;
    private backgroundCall;
    private backgroundCompaction;
    private doCompactionWork;
    private compactMemTable;
    private writeLevel0Table;
    private openCompactionOutputFile;
    private installCompactionResults;
    /**
     * manually compact
     */
    compactRange(begin: Buffer | string, end: Buffer | string): Promise<void>;
    private manualCompactRangeWithLevel;
    private manualCompactMemTable;
    private recordBackgroundError;
    private cleanupCompaction;
    private deleteObsoleteFiles;
    private finishCompactionOutputFile;
}
