/**
 * Copyright (c) 2018-present, heineiuo.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */
/// <reference types="node" />
import fs from 'fs';
export interface FileHandle extends fs.promises.FileHandle {
}
export interface Dirent extends fs.Dirent {
}
export interface Env {
    platform(): string;
    now(): number;
    access(dbpath: string): Promise<void>;
    mkdir(dbpath: string): Promise<void>;
    rename(oldpath: string, newpath: string): Promise<void>;
    readFile(dbpath: string): Promise<Buffer>;
    readFile(dbpath: string, options: {
        encoding: string;
    }): Promise<string | Buffer>;
    readFile(dbpath: string, bufferEncoding: 'utf8'): Promise<string>;
    writeFile(dbpath: string, content: Buffer | string): Promise<void>;
    open(dbpath: string, flag: string): Promise<FileHandle>;
    unlink(filename: string): Promise<void>;
    unlinkSync(filename: string): void;
    fstat(fd: FileHandle): Promise<fs.Stats>;
    readdir(dbpath: string): Promise<Dirent[]>;
}
export declare class InfoLog {
    constructor(file: FileHandle);
    private _file;
    log(message: string): Promise<void>;
}
export declare function Log(infoLog: InfoLog, message: string): Promise<void>;
export declare class NodeEnv implements Env {
    platform(): string;
    /**
     * get current time
     */
    now(): number;
    access(dbpath: string): Promise<void>;
    mkdir(dbpath: string): Promise<void>;
    writeFile: typeof fs.promises.writeFile;
    readFile: typeof fs.promises.readFile;
    open: typeof fs.promises.open;
    rename: typeof fs.promises.rename;
    unlink: typeof fs.promises.unlink;
    unlinkSync: typeof fs.unlinkSync;
    fstat: typeof fs.promises.fstat;
    readdir(dbpath: string): Promise<fs.Dirent[]>;
}
