"use strict";

exports.__esModule = true;
exports.Log = Log;
exports.NodeEnv = exports.InfoLog = void 0;

var _fs = _interopRequireDefault(require("fs"));

var _os = _interopRequireDefault(require("os"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

class InfoLog {
  constructor(file) {
    _defineProperty(this, "_file", void 0);

    this._file = file;
  }

  async log(message) {
    const finalMessage = `${new Date().toISOString()} ${message}\n`;
    await this._file.appendFile(finalMessage);
  }

}

exports.InfoLog = InfoLog;

function Log(infoLog, message) {
  if (infoLog) {
    return infoLog.log(message);
  }

  return Promise.resolve();
}

class NodeEnv {
  constructor() {
    _defineProperty(this, "writeFile", _fs.default.promises.writeFile);

    _defineProperty(this, "readFile", _fs.default.promises.readFile);

    _defineProperty(this, "open", _fs.default.promises.open);

    _defineProperty(this, "rename", _fs.default.promises.rename);

    _defineProperty(this, "unlink", _fs.default.promises.unlink);

    _defineProperty(this, "unlinkSync", _fs.default.unlinkSync);

    _defineProperty(this, "fstat", _fs.default.promises.fstat);
  }

  platform() {
    return _os.default.platform();
  }
  /**
   * get current time
   */


  now() {
    return Number(process.hrtime.bigint()) / Math.pow(10, 9);
  }

  access(dbpath) {
    return _fs.default.promises.access(dbpath, _fs.default.constants.W_OK);
  }

  mkdir(dbpath) {
    return _fs.default.promises.mkdir(dbpath, {
      recursive: true
    });
  }

  // eslint-disable-next-line
  readdir(dbpath) {
    return _fs.default.promises.readdir(dbpath, {
      withFileTypes: true
    });
  }

}

exports.NodeEnv = NodeEnv;
//# sourceMappingURL=Env.js.map