"use strict";

exports.__esModule = true;
exports.getCurrentFilename = getCurrentFilename;
exports.getLogFilename = getLogFilename;
exports.getTableFilename = getTableFilename;
exports.getManifestFilename = getManifestFilename;
exports.getLockFilename = getLockFilename;
exports.getInfoLogFilename = getInfoLogFilename;
exports.getOldInfoLogFilename = getOldInfoLogFilename;
exports.parseFilename = parseFilename;
exports.InternalFile = void 0;

var _path = _interopRequireDefault(require("path"));

var _Format = require("./Format");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function numberToString(num) {
  let str = String(num);

  while (str.length < 6) {
    str = `0${str}`;
  }

  return str;
}

function getCurrentFilename(dbpath) {
  return _path.default.resolve(dbpath, 'CURRENT');
}

function getLogFilename(dbpath, logNumber) {
  return _path.default.resolve(dbpath, `${numberToString(logNumber)}.log`);
}

function getTableFilename(dbpath, tableNumber) {
  return _path.default.resolve(dbpath, `${numberToString(tableNumber)}.ldb`);
}

function getManifestFilename(dbpath, manifestNumber) {
  return _path.default.resolve(dbpath, `MANIFEST-${numberToString(manifestNumber)}`);
}

function getLockFilename(dbpath) {
  return _path.default.resolve(dbpath, `LOCK`);
}

function getInfoLogFilename(dbpath) {
  return _path.default.resolve(dbpath, `LOG`);
}

function getOldInfoLogFilename(dbpath) {
  return _path.default.resolve(dbpath, `LOG.old`);
}

class InternalFile {
  constructor() {
    _defineProperty(this, "isInternalFile", true);

    _defineProperty(this, "filename", void 0);

    _defineProperty(this, "number", void 0);

    _defineProperty(this, "type", void 0);
  }

}

exports.InternalFile = InternalFile;

function parseFilename(filename) {
  const internalFile = new InternalFile();

  if (filename === 'CURRENT') {
    internalFile.number = 0;
    internalFile.type = _Format.FileType.kCurrentFile;
  } else if (filename === 'LOCK') {
    internalFile.number = 0;
    internalFile.type = _Format.FileType.kDBLockFile;
  } else if (filename === 'LOG' || filename === 'LOG.old') {
    internalFile.number = 0;
    internalFile.type = _Format.FileType.kInfoLogFile;
  } else if (filename.startsWith('MANIFEST-')) {
    const num = Number(filename.substr('MANIFEST-'.length));

    if (isNaN(num)) {
      internalFile.isInternalFile = false;
      return internalFile;
    }

    internalFile.number = num;
    internalFile.type = _Format.FileType.kDescriptorFile;
  } else {
    const num = Number(filename.split('.')[0]);

    if (isNaN(num)) {
      internalFile.isInternalFile = false;
      return internalFile;
    }

    const suffix = filename.substr(filename.split('.')[0].length);

    if (suffix === '.log') {
      internalFile.type = _Format.FileType.kLogFile;
    } else if (suffix === '.ldb') {
      internalFile.type = _Format.FileType.kTableFile;
    } else if (suffix === '.dbtmp') {
      internalFile.type = _Format.FileType.kTempFile;
    } else {
      internalFile.isInternalFile = false;
      return internalFile;
    }

    internalFile.number = num;
  }

  return internalFile;
}
//# sourceMappingURL=Filename.js.map