"use strict";

exports.__esModule = true;
exports.default = void 0;

var _assert = _interopRequireDefault(require("assert"));

var _bufferCrc = _interopRequireDefault(require("buffer-crc32"));

var _LogFormat = require("./LogFormat");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

class LogWriter {
  constructor(_file) {
    _defineProperty(this, "_file", void 0);

    _defineProperty(this, "_blockOffset", void 0);

    _defineProperty(this, "close", async () => {
      (0, _assert.default)(!!this._file);
      const file = this._file;
      delete this._file;

      try {
        await file.close();
      } catch (e) {}
    });

    _defineProperty(this, "emitPhysicalRecord", async (record, type) => {
      const head = Buffer.alloc(_LogFormat.kHeaderSize);
      const length = record.length;
      head[4] = length & 0xff;
      head[5] = length >> 8;
      head[6] = type;
      const crc = (0, _bufferCrc.default)(Buffer.concat([Buffer.from([type]), record, Buffer.from([record.length])]));
      head.fill(crc, 0, 4);
      this._blockOffset += record.length + _LogFormat.kHeaderSize;
      await this.appendFile(Buffer.concat([head, record]));
    });

    _defineProperty(this, "addRecord", async recordOp => {
      let hasFirstRecordCreated = false;
      let left = recordOp.size;
      let position = 0;

      while (left > 0) {
        const leftover = _LogFormat.kBlockSize - this._blockOffset;
        (0, _assert.default)(leftover >= 0);

        if (leftover < _LogFormat.kHeaderSize) {
          // Switch to a new block
          if (leftover > 0) {
            // Fill the trailer (literal below relies on kHeaderSize being 7)
            (0, _assert.default)(_LogFormat.kHeaderSize == 7);
            await this.appendFile(Buffer.alloc(leftover));
          }

          this._blockOffset = 0;
        } // Invariant: we never leave < kHeaderSize bytes in a block.


        (0, _assert.default)(_LogFormat.kBlockSize - this._blockOffset - _LogFormat.kHeaderSize >= 0);
        const avail = _LogFormat.kBlockSize - this._blockOffset - _LogFormat.kHeaderSize;
        const fragmentLength = left < avail ? left : avail;
        let recordType;
        const isEnd = left === fragmentLength;

        if (!hasFirstRecordCreated && isEnd) {
          recordType = _LogFormat.RecordType.kFullType;
        } else if (!hasFirstRecordCreated) {
          recordType = _LogFormat.RecordType.kFirstType;
        } else if (isEnd) {
          recordType = _LogFormat.RecordType.kLastType;
        } else {
          recordType = _LogFormat.RecordType.kMiddleType;
        }

        await this.emitPhysicalRecord(recordOp.buffer.slice(position, position + fragmentLength), recordType);
        hasFirstRecordCreated = true;
        position += fragmentLength;
        left -= fragmentLength;
      }
    });

    this._blockOffset = 0;
    this._file = _file;
  }

  async appendFile(buf) {
    await this._file.appendFile(buf, {});
  }

}

exports.default = LogWriter;
//# sourceMappingURL=LogWriter.js.map