"use strict";

exports.__esModule = true;
exports.Options = exports.WriteOptions = exports.IteratorOptions = exports.ReadOptions = void 0;

var _Comparator = require("./Comparator");

var _BloomFilter = _interopRequireDefault(require("./BloomFilter"));

var _Env = require("./Env");

var _Cache = _interopRequireDefault(require("./Cache"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

class ReadOptions {
  constructor() {
    _defineProperty(this, "verifyChecksums", false);

    _defineProperty(this, "fillCache", true);

    _defineProperty(this, "snapshot", void 0);
  }

}

exports.ReadOptions = ReadOptions;

class IteratorOptions extends ReadOptions {
  constructor(...args) {
    super(...args);

    _defineProperty(this, "start", Buffer.alloc(0));
  }

}

exports.IteratorOptions = IteratorOptions;

class WriteOptions {
  constructor() {
    _defineProperty(this, "sync", false);
  }

}

exports.WriteOptions = WriteOptions;

class Options {
  constructor() {
    _defineProperty(this, "comparator", new _Comparator.BytewiseComparator());

    _defineProperty(this, "writeBufferSize", 4 * 1024 * 1024);

    _defineProperty(this, "maxFileSize", 2 * 1024 * 1024);

    _defineProperty(this, "maxOpenFiles", 1000);

    _defineProperty(this, "blockCache", new _Cache.default({
      max: 2048
    }));

    _defineProperty(this, "blockSize", 4 * 1024);

    _defineProperty(this, "blockRestartInterval", 16);

    _defineProperty(this, "env", new _Env.NodeEnv());

    _defineProperty(this, "infoLog", void 0);

    _defineProperty(this, "reuseLogs", false);

    _defineProperty(this, "filterPolicy", new _BloomFilter.default());

    _defineProperty(this, "debug", false);

    _defineProperty(this, "lockfileStale", 10000);
  }

}

exports.Options = Options;
//# sourceMappingURL=Options.js.map